@@ -124,8 +124,10 @@ class LambdaHandler:
                     break
                 if hasattr(self, action):
                     result = getattr(self, action)(local_context)
-                    if result and result != response:
-                        response.set_body(result)
+                    if result is not None:
+                        raise Exception(
+                            f"Deprecated Feature Error: Action {action} returned a response but this is not allowed. Use Repsonse object instead: {type(result)}"
+                        )
                     break
             if hasattr(self, "afterAction"):
                 self.afterAction(local_context)
@@ -156,10 +158,11 @@ class LambdaHandler:
         tx.table(helpers.get_tracking_table(user or self.session)).insert(data)
 
     def OnActionDefault(self, tx, context):
-        return {"event": self.aws_event, "postdata": context.postdata()}
+        aws_event = to_json(self.aws_event)
+        context.response.set_body({"event": aws_event, "postdata": context.postdata()})
 
     def OnActionTracking(self, tx, context):
         self.track(tx, context.payload().get("data", {}))
 
     def enqueue(self, tx, action, payload={}):
-        return enqueue(tx, action, payload, self.session["email_address"])
+        enqueue(tx, action, payload, self.session["email_address"])
